@@ -149,14 +149,27 @@ class ContrastiveLearningDataset_PCL(Dataset):
 
     def perform_augmentation(self, crop):
 
+        # Obtain image patch from image crop.
+        x, y =np.random.randint(0,crop[0].shape[0]-self.patch_size+1), np.random.randint(0,crop[0].shape[0]-self.patch_size+1)        
+        aug = crop[x:self.patch_size+x,y:self.patch_size+y,:]
+
+        # Add color perturbation
+        if self.args['PCL_Color_perturbation_Augmentation']:
+            # To install the following library: pip install histomicstk --find-links https://girder.github.io/large_image_wheels
+            from histomicstk.preprocessing.augmentation.color_augmentation import rgb_perturb_stain_concentration
+            min_im = aug.min((0,1))
+            aug = aug-min_im
+            max_im = aug.max((0,1))
+            aug = aug/max_im*255        
+            aug = rgb_perturb_stain_concentration(aug)
+            aug = (((aug*max_im)/255)+min_im)
+        
+        # Define sequence of augmentations
         seq_easy = iaa.Sequential([
             iaa.CoarseDropout(0.04, size_percent=0.05, per_channel=0.5), # Drop 2% of all pixels, 15% of the original size,in 50% of all patches channeld
             iaa.Add((-0.15, 0.15), per_channel=0.5), # Add noise per channel...
             iaa.GaussianBlur(sigma=(0, 1)) # blur patches with a sigma of 0 to 3.0
-        ])
-        # data crop
-        x, y =np.random.randint(0,crop[0].shape[0]-self.patch_size+1), np.random.randint(0,crop[0].shape[0]-self.patch_size+1)        
-        aug = crop[x:self.patch_size+x,y:self.patch_size+y,:]
+        ])                
         
         # Flip lr
         if random.random()<0.5:
