@@ -241,7 +241,7 @@ def parameters(path, debug):
     elif 'LF_19H' in path:            
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
-        args['PCL_N_Workers']=10 # Number of data loading workers 
+        args['PCL_N_Workers']=0 # Number of data loading workers 
         args['PCL_Epochs']=400 # Number of total epoch to run
         args['PCL_N_Crops_per_Image']=200 # Number of crops chosen per image
         args['PCL_Patch_Size']=30 # Size of patches in pixels
@@ -256,6 +256,7 @@ def parameters(path, debug):
         args['PCL_eliminate_Black_Background'] = True
         args['PCL_eliminate_White_Background'] = False       
         args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
+        args['PCL_Color_perturbation_Augmentation'] = True # Color augmentation for H&E tissue staining.
 
         # Label you want to infer with respect the images.
         args['experiment_Label'] = ['Relapse'] 
